package com.sibatel.solarapp.ui.maintenance

import android.content.Intent
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.view.View
import android.widget.ProgressBar
import android.widget.Toast
import androidx.lifecycle.Observer
import androidx.lifecycle.ViewModelProvider
import com.sibatel.solarapp.R
import com.sibatel.solarapp.adapter.MaintenanceAdapter
import com.sibatel.solarapp.adapter.PengambilanSolarAdapter
import com.sibatel.solarapp.data.model.solar.pengambilansolar.PengambilanSolar
import com.sibatel.solarapp.data.model.tower.Maintenance
import com.sibatel.solarapp.data.viewmodel.MaintenanceViewModel
import com.sibatel.solarapp.data.viewmodel.PengambilanSolarViewModel
import com.sibatel.solarapp.databinding.ActivityMainBinding
import com.sibatel.solarapp.databinding.ActivityMaintenanceBinding
import com.sibatel.solarapp.utils.SharedPref
import com.sibatel.solarapp.utils.ViewModelFactory

class MaintenanceActivity : AppCompatActivity() {
    private lateinit var binding : ActivityMaintenanceBinding
    private lateinit var sharedPref : SharedPref

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_maintenance)

        binding = ActivityMaintenanceBinding.inflate(layoutInflater)
        setContentView(binding.root)

        sharedPref = SharedPref(this)

        binding.fab.setOnClickListener{
            val intent = Intent(this, MaintenanceMenu::class.java)
            startActivity(intent)
            finish()
        }

        val factory = ViewModelFactory.getInstance()
        val viewModelCatalog = ViewModelProvider(
            this, factory
        )[MaintenanceViewModel::class.java]

        showLoading(true)
        viewModelCatalog.getMaintenance(sharedPref.getId())
            .observe(this, Observer {
                if (it.isEmpty()){
                    Toast.makeText(this, "Data Kosong", Toast.LENGTH_LONG).show()
                }else{
                    showDataMaintenance(it)
                }
                showLoading(false)
            })
    }

    private fun showLoading(state: Boolean) {
        if (state)
            binding.progress.visibility = View.VISIBLE
        else
            binding.progress.visibility = View.GONE
    }

    private fun showDataMaintenance(listMaintenance :  ArrayList<Maintenance>?){
        binding.rvMentoringMaintenance.adapter = MaintenanceAdapter(listMaintenance)
    }
}